@@ -16,7 +16,24 @@ lmaster::~lmaster()
 }
 
 void lmaster::saveClick(){
-QString currentQuery="SELECT * FROM tracks WHERE `"+ui->comboBox->currentText()+"` LIKE '%"+ui->comboBox_2->currentText()+"%' ";
+        QString par="";
+    switch(ui->comboBox->currentIndex()){
+    case 0:
+        par="Title";
+        break;
+    case 1:
+        par="Artist";
+        break;
+    case 2:
+        par="Album";
+        break;
+    case 3:
+        par="Genre";
+       break;
+    }
+
+
+QString currentQuery="SELECT * FROM tracks WHERE `"+par+"` LIKE '%"+ui->comboBox_2->currentText()+"%' ";
 
 switch (ui->comboBox_3->currentIndex()){
 case 0:break; // no action
