@@ -24,8 +24,6 @@ void MainWindow::grabZoomKeys(bool grab)
          unsigned long val = (grab) ? 1 : 0;
          Atom atom = XInternAtom(QX11Info::display(), "_HILDON_ZOOM_KEY_ATOM", False);
          if (!atom) {
-             qWarning("Unable to obtain _HILDON_ZOOM_KEY_ATOM. This will only work "
-                      "on a Maemo 5 device!");
              return;
          }
 
@@ -181,6 +179,8 @@ MainWindow::MainWindow(QWidget *parent)    : QMainWindow(parent)
 {
 
 
+
+
 metaInformationResolver = new Phonon::MediaObject(this);
 
     ui.setupUi(this);
@@ -378,6 +378,8 @@ eq_name=get_setting("last_eq");
 if (eq_name.isEmpty())eq_name="Default";
 load_eq(eq_name);
 
+
+
 }
 
 void MainWindow::load_eqs(){
